/***********************************************************************
    UDF for modelling evaporative cooling
	D.F. Fletcher
	2 March 2021
 ************************************************************************/
 #include "udf.h"
 #include "math.h"
 #include "mem.h"
 #define F_YI_FLUX(f,t,i)F_STORAGE_R_XV(f,t,SV_SPECIES_FLUX,i) /*unit is kg/s */
 
  DEFINE_ON_DEMAND(evapflux)
 {
	real area;
	real A[ND_ND];
	Domain *d;
	Thread *t;
	Thread *t1;
	Thread *t0;
	face_t f;
	cell_t c0;
	cell_t c1;
	real tWall;
	real latent;
	
    d = Get_Domain(1);
    t = Lookup_Thread(d,8);

   begin_f_loop(f,t)
  {
	    F_AREA(A,f,t);
		area = sqrt(ND_SUM(pow(A[0],2.),pow(A[1],2.),pow(A[2],2.)));
		c0 = F_C0(f,t);
		t0 = F_C0_THREAD(f,t);
		c1 = F_C1(f,t);
		t1 = F_C1_THREAD(f,t);
		
		/* Added Latent Heat as a function of temperature */
		tWall = F_T(f,t) - 273.15;  
		latent = 1000*(2500.79 - 6.1434E-5*pow(tWall,3) + 1.58927E-3*pow(tWall,2)-2.36418*tWall);
		/* Added Latent Heat as a function of temperature */

		C_UDMI(c0,t0,0) =  F_YI_FLUX(f,t,0);
		/* udated UDMI below */
		C_UDMI(c1,t1,1) =  -F_YI_FLUX(f,t,0)*latent/C_VOLUME(c1,t1); 
	}
   end_f_loop(f,t)
 } 
  DEFINE_EXECUTE_ON_LOADING(rename_UDM, libname)
 {
	  Set_User_Memory_Name(0,"water flux (kg m^-2 s^-1)");
	  Set_User_Memory_Name(1,"heat loss (W m^-3)");
 } 
   DEFINE_SOURCE(energy_source,c,t,dS,eqn)
 {
    real source;
    source = C_UDMI(c,t,1);
    dS[eqn] = C_UDMI(c,t,1)/C_T(c,t);
    return source;
 } 

